pschunky(1)

pschunky - convert a PostScript file to CHUNKY data format

As shipped in IRIX 6.5.15. Unchanged since IRIX 6.5.

NAME
     pschunky - convert a PostScript file to CHUNKY data format

SYNOPSIS
     pschunky [-o filename] [-p pod_path]
              [-d format] [-w width] [-l length]
              [-r res] [-x hres] [-y vres]
              [-X hoff] [-Y voff] [-f] [-D]
              [PostScript input file]

DESCRIPTION
     pschunky converts a PostScript file into CHUNKY printer data format, for
     use by CHUNKY format printer drivers. Starting in Impressario 1.1, the
     CHUNKY format has been superseded by the STIFF file format (see
     libstiff(3)).  The pschunky program is provided for compatibility with
     Impressario release 1.0 and TekPhaser 1.0.  The successor program,
     psrip(1), should now be used for PostScript to raster format conversion.

   Command Line Options
     By default, pschunky assumes that its input will be arriving on standard
     input (stdin), and that its output should be written to standard output
     (stdout).  If a filename is specified after all option switches, data
     will be read from that file rather than from standard input.

     -o filename
               Specifies the name of the file to which the rasterized output
               will be sent.  If the -o option is not specified, output will
               be sent to standard output.

     -p pod_path
               Specifies the full pathname of the Printer Object Database
               (POD) files (see libpod(3)). The POD pathname is typically
               /var/spool/lp/pod/<printer_name>. If this option is specified,
               the printer specific values for output width, length,
               resolution, offset and format are filled in from the POD and
               need not be specified using command-line options.  Use of the
               -p option is preferable to manually setting the options because
               changes to the printer configuration file will then be
               reflected in the program's output. The values read from the POD
               .config file can be selectively overridden using the command-
               line options.  If POD values must be overridden, specify the
               overriding options after (to the right of) the -p option, since
               the rightmost option takes precedence. See warnings section
               below.

     -d format Specifies the output data format. The value of format may be
               one of the following: k (black only), cmy (CMY only, default),
               or cmyk (CMYK data). These data formats are described further
               in the Impressario Developer's Guide.  The data format is
               normally derived from the POD, which is kept up to date with
               the current printer configuration. Note that all output formats
               are one bit deep.
     -w width, -l length
               The -w and -l options specify the output data area in dots, in
               the horizontal (x) and vertical (y) directions, respectively.
               These values are normally derived from the POD, which is kept
               up to date with the currently loaded paper size.

     -r res, -x hres, -y vres
               The -r option specifies the printer resolution in dots per inch
               in the horizontal (x) and vertical (y) directions
               simultaneously.  These values may be set independently using
               the -x and -y options.  These values are normally derived from
               the POD, which is kept up to date with the current printer
               configuration.

     -X hoff, -Y voff
               These options specify the horizontal (x) and vertical (y)
               offsets of the frame buffer origin, respectively.  These
               options may be used to adjust the PostScript origin to
               compensate for image clipping and should be used with care.
               Values for these options are normally derived from the POD.

     -f        Specifies that the output should be in landscape orientation
               rather than portrait. Note that specifying this option simply
               creates the raster imaging framebuffer with the page width and
               height values swapped.  It is the responsibility of the
               PostScript input code to operate correctly in a landscape
               orientation.

     -D        Specifies verbose output for debugging purposes.

SEE ALSO
     psrip(1), sgi2ps(1), libpod(3), libstiff(3), and the Impressario
     Developer's Guide for a specification of the CHUNKY data format.

WARNINGS
     1.   The pschunky program is obsolete and is provided for compatibility
          with earlier versions of the Impressario product.The program may be
          removed from future releases of Impressario. Developers should use
          the psrip program and libstiff to produce and read STIFF format
          output files.

     2.   A number of undocumented and unsupported command-line options found
          in earlier releases of pschunky have been removed.

NOTE
     If pschunky is given an unrecognized or incomplete command line option
     switch, it will print a warning message to the standard error, ignore the
     option and continue processing.

KNOWN BUGS
     The command-line options for pschunky are not compliant with the
     Impressario Filter-Driver Specification.

FILES
     /usr/lib/print/pschunky                Program file
     /usr/lib/print/psrip                   PostScript interpreter used by
                                            pschunky.
     /usr/lib/print/data/PSRIPmasterDPSVM   DPS Virtual Memory file
     /usr/lib/print/data/PSRIPstartup.ps    Startup code (optional)
     /usr/lib/DPS                           Display PostScript font and
                                            support directory
     /usr/lib/print/data/DPSprolog          Apple LaserWriter statusdict
                                            emulation prolog (optional)

TRADEMARKS
     PostScript is a registered trademark of Adobe Systems, Inc.